@@ -9,8 +9,7 @@ SPDX-License-Identifier: GPL-2.0-or-later
 #pragma once
 
 #include <KConfigPropertyMap>
-#include <KPackage/Package>
-#include <KQuickAddons/ManagedConfigModule>
+#include <KQuickManagedConfigModule>
 
 #include "kscreensaversettings.h"
 #include "wallpaper_integration.h"
@@ -22,11 +21,11 @@ namespace ScreenLocker
 class LnFIntegration;
 }
 
-class ScreenLockerKcm : public KQuickAddons::ManagedConfigModule
+class ScreenLockerKcm : public KQuickManagedConfigModule
 {
     Q_OBJECT
 public:
-    explicit ScreenLockerKcm(QObject *parent, const KPluginMetaData &data, const QVariantList &args);
+    explicit ScreenLockerKcm(QObject *parent, const KPluginMetaData &data);
 
     Q_PROPERTY(KScreenSaverSettings *settings READ settings CONSTANT)
     Q_PROPERTY(KConfigPropertyMap *wallpaperConfiguration READ wallpaperConfiguration NOTIFY currentWallpaperChanged)
@@ -37,7 +36,7 @@ public:
     Q_PROPERTY(QString currentWallpaper READ currentWallpaper NOTIFY currentWallpaperChanged)
     Q_PROPERTY(bool isDefaultsAppearance READ isDefaultsAppearance NOTIFY isDefaultsAppearanceChanged)
 
-    Q_INVOKABLE QVector<WallpaperInfo> availableWallpaperPlugins()
+    Q_INVOKABLE QList<WallpaperInfo> availableWallpaperPlugins()
     {
         return KScreenSaverSettings::getInstance().availableWallpaperPlugins();
     }
